@@ -21,30 +21,27 @@
 package cmd
 
 import (
+	"bufio"
 	"bytes"
 	"fmt"
 	"io"
 	"os"
 	"runtime"
-	"syscall"
+	"strings"
 
 	// "runtime/debug"
 
+	gzip "github.com/klauspost/pgzip"
 	"github.com/shenwei356/bio/seq"
 	"github.com/shenwei356/bio/seqio/fastx"
-	"github.com/shenwei356/util/byteutil"
 	"github.com/spf13/cobra"
 )
 
 // seqCmd represents the seq command
 var seqCmd = &cobra.Command{
 	Use:   "seq",
-	Short: "transform sequences (revserse, complement, extract ID...)",
-	Long: `transform sequences (revserse, complement, extract ID...)
-
-Attentions:
-
-  1. This command outputs plain text even when out file ends with ".gz".
+	Short: "transform sequences (extract ID, filter by length, remove gaps...)",
+	Long: `transform sequences (extract ID, filter by length, remove gaps...)
 
 `,
 	Run: func(cmd *cobra.Command, args []string) {
@@ -78,6 +75,11 @@ Attentions:
 		minQual := getFlagFloat64(cmd, "min-qual")
 		maxQual := getFlagFloat64(cmd, "max-qual")
 
+		filterMinLen := minLen > 0
+		filterMaxLen := maxLen > 0
+		filterMinQual := minQual > 0
+		filterMaxQual := maxQual > 0
+
 		if gapLetters == "" {
 			checkError(fmt.Errorf("value of flag -G (--gap-letters) should not be empty"))
 		}
@@ -137,6 +139,10 @@ Attentions:
 			default:
 				seqCol = NewSeqColorizer("nucleic")
 			}
+
+			if outFile != "-" {
+				log.Warning("flag -k/--color only applies for stdout")
+			}
 		}
 		var outfh *os.File
 		var err error
@@ -145,21 +151,44 @@ Attentions:
 		} else {
 			outfh, err = os.Create(outFile)
 			checkError(err)
+			color = false
 		}
-		defer outfh.Close()
-		var outbw io.Writer
-		outbw = outfh
+
+		gzippedOutfile := strings.HasSuffix(strings.ToLower(outFile), ".gz")
+
+		var fh io.Writer
+		var outbw *bufio.Writer
+		var gw *gzip.Writer
+
 		if color {
-			outbw = seqCol.WrapWriter(outfh)
+			fh = seqCol.WrapWriter(outfh)
+			outbw = bufio.NewWriterSize(fh, bufSize)
+		} else if gzippedOutfile {
+			gw = gzip.NewWriter(outfh)
+			outbw = bufio.NewWriterSize(gw, bufSize)
+		} else {
+			fh = outfh
+			outbw = bufio.NewWriterSize(fh, bufSize)
 		}
 
+		defer func() {
+			outbw.Flush()
+			if gzippedOutfile {
+				err = gw.Flush()
+				checkError(err)
+				gw.Close()
+			}
+
+			outfh.Close()
+		}()
+
 		var checkSeqType bool
 		var isFastq bool
 		var printName, printSeq, printQual bool
 		var head []byte
 		var sequence *seq.Seq
 		var text []byte
-		var b *bytes.Buffer
+		var buffer *bytes.Buffer
 		var record *fastx.Record
 		var fastxReader *fastx.Reader
 
@@ -196,20 +225,20 @@ Attentions:
 					record.Seq.RemoveGapsInplace(gapLetters)
 				}
 
-				if minLen >= 0 && len(record.Seq.Seq) < minLen {
+				if filterMinLen && len(record.Seq.Seq) < minLen {
 					continue
 				}
 
-				if maxLen >= 0 && len(record.Seq.Seq) > maxLen {
+				if filterMaxLen && len(record.Seq.Seq) > maxLen {
 					continue
 				}
 
-				if minQual > 0 || maxQual > 0 {
+				if filterMinQual || filterMaxQual {
 					avgQual := record.Seq.AvgQual(qBase)
-					if minQual > 0 && avgQual < minQual {
+					if filterMinQual && avgQual < minQual {
 						continue
 					}
-					if maxQual > 0 && avgQual >= maxQual {
+					if filterMaxQual && avgQual >= maxQual {
 						continue
 					}
 				}
@@ -236,17 +265,17 @@ Attentions:
 
 					if printSeq {
 						if isFastq {
-							outbw.Write([]byte("@"))
+							outbw.Write(_mark_fastq)
 							outbw.Write(head)
-							outbw.Write([]byte("\n"))
+							outbw.Write(_mark_newline)
 						} else {
-							outbw.Write([]byte(">"))
+							outbw.Write(_mark_fasta)
 							outbw.Write(head)
-							outbw.Write([]byte("\n"))
+							outbw.Write(_mark_newline)
 						}
 					} else {
 						outbw.Write(head)
-						outbw.Write([]byte("\n"))
+						outbw.Write(_mark_newline)
 					}
 				}
 
@@ -304,8 +333,19 @@ Attentions:
 						sequence.Seq = bytes.ToUpper(sequence.Seq)
 					}
 
-					if len(sequence.Seq) <= pageSize {
-						text := byteutil.WrapByteSlice(sequence.Seq, config.LineWidth)
+					if isFastq {
+						if color {
+							if sequence.Qual != nil {
+								outbw.Write(seqCol.ColorWithQuals(sequence.Seq, sequence.Qual))
+							} else {
+								outbw.Write(seqCol.Color(sequence.Seq))
+							}
+						} else {
+							outbw.Write(sequence.Seq)
+						}
+					} else {
+						text, buffer = wrapByteSlice(sequence.Seq, config.LineWidth, buffer)
+
 						if color {
 							if sequence.Qual != nil {
 								text = seqCol.ColorWithQuals(text, sequence.Qual)
@@ -313,57 +353,35 @@ Attentions:
 								text = seqCol.Color(text)
 							}
 						}
+
 						outbw.Write(text)
-					} else {
-						if bufferedByteSliceWrapper == nil {
-							bufferedByteSliceWrapper = byteutil.NewBufferedByteSliceWrapper2(1, len(sequence.Seq), config.LineWidth)
-						}
-						text, b = bufferedByteSliceWrapper.Wrap(sequence.Seq, config.LineWidth)
-						if color {
-							text = seqCol.Color(text)
-						}
-						outbw.Write(text)
-						bufferedByteSliceWrapper.Recycle(b)
 					}
 
-					outbw.Write([]byte("\n"))
+					outbw.Write(_mark_newline)
 				}
 
 				if printQual {
 					if !onlyQual {
-						outbw.Write([]byte("+\n"))
+						outbw.Write(_mark_plus_newline)
 					}
 
-					if len(sequence.Qual) <= pageSize {
-						if color {
-							outbw.Write(byteutil.WrapByteSlice(seqCol.ColorQuals(sequence.Qual), config.LineWidth))
-						} else {
-							outbw.Write(byteutil.WrapByteSlice(sequence.Qual, config.LineWidth))
-						}
+					if color {
+						outbw.Write(seqCol.ColorQuals(sequence.Qual))
 					} else {
-						if bufferedByteSliceWrapper == nil {
-							bufferedByteSliceWrapper = byteutil.NewBufferedByteSliceWrapper2(1, len(sequence.Qual), config.LineWidth)
-						}
-						text, b = bufferedByteSliceWrapper.Wrap(sequence.Qual, config.LineWidth)
-						if color {
-							text = seqCol.ColorQuals(text)
-						}
-						outbw.Write(text)
-						bufferedByteSliceWrapper.Recycle(b)
+						outbw.Write(sequence.Qual)
 					}
 
-					outbw.Write([]byte("\n"))
+					outbw.Write(_mark_newline)
 				}
 			}
 
 			config.LineWidth = lineWidth
 		}
 
-		outfh.Close()
 	},
 }
 
-var pageSize = syscall.Getpagesize()
+var bufSize = 65536
 
 func init() {
 	RootCmd.AddCommand(seqCmd)
@@ -389,3 +407,8 @@ func init() {
 	seqCmd.Flags().Float64P("min-qual", "Q", -1, "only print sequences with average quality qreater or equal than this limit (-1 for no limit)")
 	seqCmd.Flags().Float64P("max-qual", "R", -1, "only print sequences with average quality less than this limit (-1 for no limit)")
 }
+
+var _mark_fasta = []byte{'>'}
+var _mark_fastq = []byte{'@'}
+var _mark_plus_newline = []byte{'+', '\n'}
+var _mark_newline = []byte{'\n'}
