@@ -196,7 +196,7 @@ Examples:
 					newFile = file + ".fastx"
 				}
 				if !quiet {
-					log.Infof("read and write sequences to tempory file: %s ...", newFile)
+					log.Infof("read and write sequences to temporary file: %s ...", newFile)
 				}
 
 				var nseqs int
@@ -362,7 +362,7 @@ Examples:
 					newFile = file + ".fastx"
 				}
 				if !quiet {
-					log.Infof("read and write sequences to tempory file: %s ...", newFile)
+					log.Infof("read and write sequences to temporary file: %s ...", newFile)
 				}
 
 				var nseqs int
@@ -458,11 +458,17 @@ Examples:
 					j = 0
 				}
 			}
-			if j > 0 && !quiet {
-				log.Infof("write %d sequences to file: %s\n", j, outfile)
-			}
-			if !dryRun {
-				outfh.Close()
+			if j > 0 {
+				if quiet {
+					log.Infof("write %d sequences to file: %s\n", j, outfile)
+				}
+				if !dryRun {
+					outfh.Close()
+				}
+			} else {
+				if !dryRun {
+					checkError(os.Remove(outfile))
+				}
 			}
 
 			if (isstdin || !isPlainFile(file)) && !keepTemp {
@@ -531,7 +537,7 @@ Examples:
 					newFile = file + ".fastx"
 				}
 				if !quiet {
-					log.Infof("read and write sequences to tempory file: %s ...", newFile)
+					log.Infof("read and write sequences to temporary file: %s ...", newFile)
 				}
 
 				var nseqs int
@@ -555,7 +561,7 @@ Examples:
 				}
 				if isFastq {
 					checkError(os.Remove(newFile))
-					checkError(fmt.Errorf("Sorry, two-pass mode does not support FASTQ format"))
+					checkError(fmt.Errorf("sorry, two-pass mode does not support FASTQ format"))
 				}
 			}
 			fileExt = suffixFA
@@ -722,7 +728,7 @@ Examples:
 					newFile = file + ".fastx"
 				}
 				if !quiet {
-					log.Infof("read and write sequences to tempory file: %s ...", newFile)
+					log.Infof("read and write sequences to temporary file: %s ...", newFile)
 				}
 
 				var nseqs int
@@ -854,7 +860,7 @@ func init() {
 		`e.g 1:12 for first 12 bases, -12:-1 for last 12 bases. type "seqkit split -h" for more examples`)
 	splitCmd.Flags().BoolP("two-pass", "2", false, "two-pass mode read files twice to lower memory usage. (only for FASTA format)")
 	splitCmd.Flags().BoolP("dry-run", "d", false, "dry run, just print message and no files will be created.")
-	splitCmd.Flags().BoolP("keep-temp", "k", false, "keep tempory FASTA and .fai file when using 2-pass mode")
+	splitCmd.Flags().BoolP("keep-temp", "k", false, "keep temporary FASTA and .fai file when using 2-pass mode")
 	splitCmd.Flags().StringP("out-dir", "O", "", "output directory (default value is $infile.split)")
 	splitCmd.Flags().BoolP("force", "f", false, "overwrite output directory")
 }
